eprllib.RewardFunctions.comfort_rewards — eprllib: use EnergyPlus as an environment for DRL control

Skip to main content
`Ctrl`+`K`

# eprllib.RewardFunctions.comfort_rewards

## Comfort rewards

The rewards based on comfort variables/meters.

### Herarchical versions

Note that herarchical versions are the same function but insteade of using only the inmediate value of the variable/meter, the reward is calculated using a List of the last timesteps and integrating or averaging them.

Classes

`ashrae55simplemodel`(reward_fn_config) |
`cen15251`(reward_fn_config) | The standard CEN 15251 stablish three categories of acceptability of the thermal condition as is show in table below.
`herarchical_ashrae55simplemodel`(reward_fn_config) |
`herarchical_cen15251`(reward_fn_config) |